@@ -112,3 +112,15 @@ model_get_coefficients_type.clmm <- function(model) {
 model_get_coefficients_type.coxph <- function(model) {
   "prop_hazard"
 }
+
+#' @export
+#' @rdname model_get_coefficients_type
+model_get_coefficients_type.crr <- function(model) {
+  "prop_hazard"
+}
+
+#' @export
+#' @rdname model_get_coefficients_type
+model_get_coefficients_type.tidycrr <- function(model) {
+  "prop_hazard"
+}
