@@ -1,13 +1,31 @@
 #' Convert formula selector to a named list
 #'
-#' Functions takes a list of formulas, e.g. `list(starts_with("age") ~ "continuous")`,
-#' and returns a named list, e.g. `list(age = "continuous")`.
+#' Functions takes a list of formulas, a named list, or a combination of named
+#' elements with formula elements and returns a named list.
+#' For example, `list(age = 1, starts_with("stage") ~ 2)`.
+#'
+#' @section Shortcuts:
+#' A shortcut for specifying an option be applied to all columns/variables
+#' is omitting the LHS of the formula.
+#' For example, `list(~ 1)` is equivalent to passing `list(everything() ~ 1)`.
+#'
+#' Additionally, a single formula may be passed instead of placing a single
+#' formula in a list; e.g. `everything() ~ 1` is equivalent to
+#' passing `list(everything() ~ 1)`
 #'
 #' @param x list of selecting formulas
+#' @param type_check A predicate function that checks the elements passed on
+#' the RHS of the formulas in `x=` (or the element in a named list)
+#' satisfy the function.
+#' @param type_check_msg When the `type_check=` fails, the string provided
+#' here will be printed as the error message. When `NULL`, a generic
+#' error message will be printed.
 #' @inheritParams .select_to_varnames
+#'
 #' @export
 .formula_list_to_named_list <- function(x, data = NULL, var_info = NULL,
-                                        arg_name = NULL, select_single = FALSE) {
+                                        arg_name = NULL, select_single = FALSE,
+                                        type_check = NULL, type_check_msg = NULL) {
   # if NULL provided, return NULL ----------------------------------------------
   if (is.null(x)) {
     return(NULL)
@@ -18,6 +36,9 @@
     x <- list(x)
   }
 
+  # checking the input is valid ------------------------------------------------
+  .check_valid_input(x = x, arg_name = arg_name, type_check = type_check)
+
   # convert to a named list ----------------------------------------------------
   len_x <- length(x)
   named_list <- vector(mode = "list", length = len_x)
@@ -31,7 +52,9 @@
                                 data = data,
                                 var_info = var_info,
                                 arg_name = arg_name,
-                                select_single = select_single) %>%
+                                select_single = select_single,
+                                type_check = type_check,
+                                type_check_msg = type_check_msg) %>%
         list()
     }
     else {
@@ -45,7 +68,39 @@
   named_list[tokeep]
 }
 
-.single_formula_to_list <- function(x, data, var_info, arg_name, select_single) {
+.check_valid_input <- function(x, arg_name, type_check) {
+  if (!rlang::is_list(x) &&
+      !(rlang::is_vector(x) && rlang::is_named(x))) {
+    err_msg <-
+      stringr::str_glue(
+        "Error processing the `{arg_name %||% ''}` argument. ",
+        "Expecting a list or formula.\n",
+        "Review syntax details at",
+        "'https://www.danieldsjoberg.com/gtsummary/reference/syntax.html'")
+    if (tryCatch(do.call(type_check, list(x)), error = function(e) FALSE)) {
+      x_string <-
+        suppressWarnings(tryCatch(
+          switch(rlang::is_string(x)) %||% as.character(deparse(x)),
+          error = function(e) NULL
+        ))
+      if (!is.null(x_string) && nchar(x_string) <= 50) {
+        err_msg <-
+          paste(
+            err_msg,
+            stringr::str_glue("Did you mean `everything() ~ {x_string}`?"),
+            sep = "\n\n"
+          )
+      }
+    }
+
+    stop(err_msg, call. = FALSE)
+  }
+
+  return(invisible())
+}
+
+.single_formula_to_list <- function(x, data, var_info, arg_name,
+                                    select_single, type_check, type_check_msg) {
   # for each formula extract lhs and rhs ---------------------------------
   # checking the LHS is not empty
   f_lhs_quo <- .f_side_as_quo(x, "lhs")
@@ -60,6 +115,15 @@
   # evaluate RHS of formula in the original formula environment
   rhs <- .f_side_as_quo(x, "rhs") %>% rlang::eval_tidy()
 
+  # check the type of RHS ------------------------------------------------------
+  if (!is.null(type_check) && !type_check(rhs)) {
+    type_check_msg %||%
+      stringr::str_glue(
+        "Error processing `{arg_name %||% ''}` argument for element '{lhs[[1]]}'. ",
+        "The value passed is not the expected type/class.") %>%
+      stop(call. = FALSE)
+  }
+
   # converting rhs and lhs into a named list
   purrr::map(lhs, ~ list(rhs) %>% rlang::set_names(.x)) %>%
     purrr::flatten()
