@@ -278,6 +278,20 @@ test_that("select_helpers: .formula_list_to_named_list ", {
     .formula_list_to_named_list(list(age ~ "Age", TRUE), var_info = tidy_mod)
   )
 
+  expect_error(
+    .formula_list_to_named_list(list(age ~ "Age"), var_info = tidy_mod,
+                                type_check = is.character),
+    NA
+  )
+  expect_error(
+    .formula_list_to_named_list(list(age ~ "Age"), var_info = tidy_mod,
+                                type_check = is.logical)
+  )
+  expect_error(
+    .formula_list_to_named_list(letters, var_info = tidy_mod,
+                                type_check = is.logical)
+  )
+
   expect_equal(
     .formula_list_to_named_list(age ~ "Age", var_info = tidy_mod),
     list(age = "Age")
@@ -291,6 +305,36 @@ test_that("select_helpers: .formula_list_to_named_list ", {
     .formula_list_to_named_list(list(~ "Age", `age:trt` = "interact"), var_info = tidy_mod),
     list(age = "Age", trt = "Age", grade = "Age", `age:trt` = "interact")
   )
+
+  expect_error(
+    .formula_list_to_named_list(list(age ~ "Age"), var_info = tidy_mod, type_check = is.logical,
+                                arg_name = "label")
+  )
+  expect_error(
+    .formula_list_to_named_list(list(age ~ "Age"), var_info = tidy_mod,
+                                type_check = is.logical, arg_name = "label",
+                                type_check_msg = "Age msg error"),
+    "Age msg error"
+  )
+  expect_error(
+    .formula_list_to_named_list("Age", var_info = tidy_mod,
+                                type_check = rlang::is_string,
+                                arg_name = "label"),
+    "Did you mean `everything"
+  )
+  expect_error(
+    .formula_list_to_named_list("Age", var_info = tidy_mod,
+                                type_check = rlang::is_string,
+                                arg_name = "label"),
+    "Age"
+  )
+  expect_error(
+    .formula_list_to_named_list(~ "Age", var_info = tidy_mod,
+                                type_check = rlang::is_string,
+                                arg_name = "label"),
+    NA
+  )
+
 })
 
 
